==> jc-1.4.0.tar.gz: soot/jimple/toolkits/callgraph/ExplicitEdgesPred.h <==
// public class soot.jimple.toolkits.callgraph.ExplicitEdgesPred

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 7f4d28cb7ff83472 soot_jimple_toolkits_callgraph_ExplicitEdgesPred

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_callgraph_ExplicitEdgesPred_H_
#define _JC_soot_jimple_toolkits_callgraph_ExplicitEdgesPred_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_jimple_toolkits_callgraph_Edge$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_callgraph_ExplicitEdgesPred$sub_refs	_jc_soot_jimple_toolkits_callgraph_ExplicitEdgesPred$sub_refs;
typedef struct _jc_soot_jimple_toolkits_callgraph_ExplicitEdgesPred$sub_nonrefs	_jc_soot_jimple_toolkits_callgraph_ExplicitEdgesPred$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_callgraph_ExplicitEdgesPred$refs	_jc_soot_jimple_toolkits_callgraph_ExplicitEdgesPred$refs;
typedef struct _jc_soot_jimple_toolkits_callgraph_ExplicitEdgesPred$nonrefs	_jc_soot_jimple_toolkits_callgraph_ExplicitEdgesPred$nonrefs;
typedef struct _jc_soot_jimple_toolkits_callgraph_ExplicitEdgesPred$object	_jc_soot_jimple_toolkits_callgraph_ExplicitEdgesPred$object;

typedef const struct _jc_soot_jimple_toolkits_callgraph_ExplicitEdgesPred$vmethods	_jc_soot_jimple_toolkits_callgraph_ExplicitEdgesPred$vmethods;
typedef const struct _jc_soot_jimple_toolkits_callgraph_ExplicitEdgesPred$vtable	_jc_soot_jimple_toolkits_callgraph_ExplicitEdgesPred$vtable;
typedef const struct _jc_soot_jimple_toolkits_callgraph_ExplicitEdgesPred$vtype	_jc_soot_jimple_toolkits_callgraph_ExplicitEdgesPred$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_callgraph_ExplicitEdgesPred$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_ExplicitEdgesPred$object *);

// Virtual methods
extern jboolean _jc_soot_jimple_toolkits_callgraph_ExplicitEdgesPred$method$want$6d4f4c7f183187ef(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_ExplicitEdgesPred$object *, struct _jc_soot_jimple_toolkits_callgraph_Edge$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_callgraph_ExplicitEdgesPred$method_info$want$6d4f4c7f183187ef;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_callgraph_ExplicitEdgesPred$vmethods {
	jboolean	(*want$6d4f4c7f183187ef)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_ExplicitEdgesPred$object *, struct _jc_soot_jimple_toolkits_callgraph_Edge$object *);
};

// Vtable
struct _jc_soot_jimple_toolkits_callgraph_ExplicitEdgesPred$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_callgraph_ExplicitEdgesPred$vmethods	soot_jimple_toolkits_callgraph_ExplicitEdgesPred;
};

// Vtype
struct _jc_soot_jimple_toolkits_callgraph_ExplicitEdgesPred$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_callgraph_ExplicitEdgesPred$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_callgraph_ExplicitEdgesPred$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_callgraph_ExplicitEdgesPred$refs {
    _jc_soot_jimple_toolkits_callgraph_ExplicitEdgesPred$sub_refs	soot_jimple_toolkits_callgraph_ExplicitEdgesPred;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_callgraph_ExplicitEdgesPred$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_callgraph_ExplicitEdgesPred$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_callgraph_ExplicitEdgesPred$sub_nonrefs	soot_jimple_toolkits_callgraph_ExplicitEdgesPred;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_callgraph_ExplicitEdgesPred$object {
	_jc_soot_jimple_toolkits_callgraph_ExplicitEdgesPred$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_callgraph_ExplicitEdgesPred$vtype	*vtype;
	_jc_soot_jimple_toolkits_callgraph_ExplicitEdgesPred$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_callgraph_ExplicitEdgesPred$vtype _jc_soot_jimple_toolkits_callgraph_ExplicitEdgesPred$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_callgraph_ExplicitEdgesPred, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_callgraph_ExplicitEdgesPred$class_object;

#endif	/* _JC_soot_jimple_toolkits_callgraph_ExplicitEdgesPred_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/toolkits/callgraph/ExplicitEdgesPred.h <==
// public class soot.jimple.toolkits.callgraph.ExplicitEdgesPred

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 7f4d28cb7ff83472 soot_jimple_toolkits_callgraph_ExplicitEdgesPred

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_callgraph_ExplicitEdgesPred_H_
#define _JC_soot_jimple_toolkits_callgraph_ExplicitEdgesPred_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_jimple_toolkits_callgraph_Edge$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_callgraph_ExplicitEdgesPred$sub_refs	_jc_soot_jimple_toolkits_callgraph_ExplicitEdgesPred$sub_refs;
typedef struct _jc_soot_jimple_toolkits_callgraph_ExplicitEdgesPred$sub_nonrefs	_jc_soot_jimple_toolkits_callgraph_ExplicitEdgesPred$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_callgraph_ExplicitEdgesPred$refs	_jc_soot_jimple_toolkits_callgraph_ExplicitEdgesPred$refs;
typedef struct _jc_soot_jimple_toolkits_callgraph_ExplicitEdgesPred$nonrefs	_jc_soot_jimple_toolkits_callgraph_ExplicitEdgesPred$nonrefs;
typedef struct _jc_soot_jimple_toolkits_callgraph_ExplicitEdgesPred$object	_jc_soot_jimple_toolkits_callgraph_ExplicitEdgesPred$object;

typedef const struct _jc_soot_jimple_toolkits_callgraph_ExplicitEdgesPred$vmethods	_jc_soot_jimple_toolkits_callgraph_ExplicitEdgesPred$vmethods;
typedef const struct _jc_soot_jimple_toolkits_callgraph_ExplicitEdgesPred$vtable	_jc_soot_jimple_toolkits_callgraph_ExplicitEdgesPred$vtable;
typedef const struct _jc_soot_jimple_toolkits_callgraph_ExplicitEdgesPred$vtype	_jc_soot_jimple_toolkits_callgraph_ExplicitEdgesPred$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_callgraph_ExplicitEdgesPred$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_ExplicitEdgesPred$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_soot_jimple_toolkits_callgraph_ExplicitEdgesPred$method$want$6d4f4c7f183187ef(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_ExplicitEdgesPred$object *, struct _jc_soot_jimple_toolkits_callgraph_Edge$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_callgraph_ExplicitEdgesPred$method_info$want$6d4f4c7f183187ef;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_callgraph_ExplicitEdgesPred$vmethods {
	jboolean	(*want$6d4f4c7f183187ef)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_ExplicitEdgesPred$object *, struct _jc_soot_jimple_toolkits_callgraph_Edge$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_toolkits_callgraph_ExplicitEdgesPred$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_callgraph_ExplicitEdgesPred$vmethods	soot_jimple_toolkits_callgraph_ExplicitEdgesPred;
};

// Vtype
struct _jc_soot_jimple_toolkits_callgraph_ExplicitEdgesPred$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_callgraph_ExplicitEdgesPred$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_callgraph_ExplicitEdgesPred$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_callgraph_ExplicitEdgesPred$refs {
    _jc_soot_jimple_toolkits_callgraph_ExplicitEdgesPred$sub_refs	soot_jimple_toolkits_callgraph_ExplicitEdgesPred;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_callgraph_ExplicitEdgesPred$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_callgraph_ExplicitEdgesPred$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_callgraph_ExplicitEdgesPred$sub_nonrefs	soot_jimple_toolkits_callgraph_ExplicitEdgesPred;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_callgraph_ExplicitEdgesPred$object {
	_jc_soot_jimple_toolkits_callgraph_ExplicitEdgesPred$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_callgraph_ExplicitEdgesPred$vtype	*vtype;
	_jc_soot_jimple_toolkits_callgraph_ExplicitEdgesPred$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_callgraph_ExplicitEdgesPred$vtype _jc_soot_jimple_toolkits_callgraph_ExplicitEdgesPred$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_callgraph_ExplicitEdgesPred, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_callgraph_ExplicitEdgesPred$class_object;

#endif	/* _JC_soot_jimple_toolkits_callgraph_ExplicitEdgesPred_H_ */
